==> huaweicloudsdkec-3.1.90-py2.py3-none-any.whl: huaweicloudsdkec/v1/model/update_access_point_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAccessPointRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'region_id': 'str',
        'bandwidth_size': 'int'
    }

    attribute_map = {
        'region_id': 'region_id',
        'bandwidth_size': 'bandwidth_size'
    }

    def __init__(self, region_id=None, bandwidth_size=None):
        """UpdateAccessPointRequestBody

        The model defined in huaweicloud sdk

        :param region_id: 区域ID
        :type region_id: str
        :param bandwidth_size: 带宽
        :type bandwidth_size: int
        """
        
        

        self._region_id = None
        self._bandwidth_size = None
        self.discriminator = None

        self.region_id = region_id
        self.bandwidth_size = bandwidth_size

    @property
    def region_id(self):
        """Gets the region_id of this UpdateAccessPointRequestBody.

        区域ID

        :return: The region_id of this UpdateAccessPointRequestBody.
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this UpdateAccessPointRequestBody.

        区域ID

        :param region_id: The region_id of this UpdateAccessPointRequestBody.
        :type region_id: str
        """
        self._region_id = region_id

    @property
    def bandwidth_size(self):
        """Gets the bandwidth_size of this UpdateAccessPointRequestBody.

        带宽

        :return: The bandwidth_size of this UpdateAccessPointRequestBody.
        :rtype: int
        """
        return self._bandwidth_size

    @bandwidth_size.setter
    def bandwidth_size(self, bandwidth_size):
        """Sets the bandwidth_size of this UpdateAccessPointRequestBody.

        带宽

        :param bandwidth_size: The bandwidth_size of this UpdateAccessPointRequestBody.
        :type bandwidth_size: int
        """
        self._bandwidth_size = bandwidth_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccessPointRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkec-3.1.154-py2.py3-none-any.whl: huaweicloudsdkec/v1/model/update_access_point_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAccessPointRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'region_id': 'str',
        'bandwidth_size': 'int'
    }

    attribute_map = {
        'region_id': 'region_id',
        'bandwidth_size': 'bandwidth_size'
    }

    def __init__(self, region_id=None, bandwidth_size=None):
        r"""UpdateAccessPointRequestBody

        The model defined in huaweicloud sdk

        :param region_id: 区域ID
        :type region_id: str
        :param bandwidth_size: 带宽
        :type bandwidth_size: int
        """
        
        

        self._region_id = None
        self._bandwidth_size = None
        self.discriminator = None

        self.region_id = region_id
        self.bandwidth_size = bandwidth_size

    @property
    def region_id(self):
        r"""Gets the region_id of this UpdateAccessPointRequestBody.

        区域ID

        :return: The region_id of this UpdateAccessPointRequestBody.
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        r"""Sets the region_id of this UpdateAccessPointRequestBody.

        区域ID

        :param region_id: The region_id of this UpdateAccessPointRequestBody.
        :type region_id: str
        """
        self._region_id = region_id

    @property
    def bandwidth_size(self):
        r"""Gets the bandwidth_size of this UpdateAccessPointRequestBody.

        带宽

        :return: The bandwidth_size of this UpdateAccessPointRequestBody.
        :rtype: int
        """
        return self._bandwidth_size

    @bandwidth_size.setter
    def bandwidth_size(self, bandwidth_size):
        r"""Sets the bandwidth_size of this UpdateAccessPointRequestBody.

        带宽

        :param bandwidth_size: The bandwidth_size of this UpdateAccessPointRequestBody.
        :type bandwidth_size: int
        """
        self._bandwidth_size = bandwidth_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccessPointRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
